@@ -71,6 +71,8 @@ void                gdm_manager_set_wait_for_go                (GdmManager *mana
 
 void                gdm_manager_set_xdmcp_enabled              (GdmManager *manager,
                                                                 gboolean    enabled);
+void                gdm_manager_set_show_local_greeter         (GdmManager *manager,
+                                                                gboolean    show_local_greeter);
 gboolean            gdm_manager_get_displays                   (GdmManager *manager,
                                                                 GPtrArray **displays,
                                                                 GError    **error);
